django-db-call
==============

.. image:: https://travis-ci.org/paetzke/django-db-call.png?branch=master
  :target: https://travis-ci.org/paetzke/django-db-call
.. image:: https://coveralls.io/repos/paetzke/django-db-call/badge.png?branch=master
  :target: https://coveralls.io/r/paetzke/django-db-call?branch=master

Copyright (c) 2014, Friedrich Paetzke (f.paetzke@gmail.com)
All rights reserved.

.. image:: https://d2weczhvl823v0.cloudfront.net/paetzke/django-db-call/trend.png

